@@ -9,7 +9,10 @@ def setup():
     if os.getenv('DJANGO_SETTINGS_MODULE') is not None:
         return
 
-    MAILMAN_WEB_CONFIG = os.getenv('MAILMAN_WEB_CONFIG', '/etc/webapps/mailman-web/settings.py')
+    MAILMAN_WEB_CONFIG = os.getenv(
+        'MAILMAN_WEB_CONFIG',
+        '/etc/webapps/mailman-web/settings.py',
+    )
 
     if not os.path.exists(MAILMAN_WEB_CONFIG):
         print('Mailman web configuration file at {} does not exist'.format(
