@@ -1,6 +1,6 @@
 # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
 import os
-from django.contrib.messages import constants as messages  # flake8: noqa
+from django.contrib.messages import constants as messages
 from pathlib import Path
 
 #: The base directory for logs and database.
@@ -131,8 +131,9 @@ WSGI_APPLICATION = 'mailman_web.wsgi.application'
 #:     'OPTIONS': {'charset': 'utf8mb4'}  # Enable utf8 4-byte encodings.
 #:
 #: Check out
-#: `Django documentation <https://docs.djangoproject.com/en/3.0/ref/settings/#databases>`_
-#: for more details.
+#: `Django documentation
+#: <https://docs.djangoproject.com/en/3.0/ref/settings/#databases>`_ for
+#: more details.
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -147,7 +148,7 @@ DATABASES = {
 AUTH_PASSWORD_VALIDATORS = [
     {
         'NAME':
-        'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
+        'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',  # noqa: E501
     },
     {
         'NAME':
@@ -250,7 +251,7 @@ LOGGING = {
         'file': {
             'level': 'INFO',
             'class': 'logging.handlers.WatchedFileHandler',
-            'filename': Path("/var/log/mailman-web/mailman-web.log"),
+            'filename': Path('/var/log/mailman-web/mailman-web.log'),
             'formatter': 'verbose',
         },
         'console': {
@@ -281,7 +282,7 @@ LOGGING = {
     },
     'formatters': {
         'verbose': {
-            'format': '%(levelname)s %(asctime)s %(process)d %(name)s %(message)s'
+            'format': '%(levelname)s %(asctime)s %(process)d %(name)s %(message)s'  # noqa: E501
         },
         'simple': {
             'format': '%(levelname)s %(message)s'
